@@ -33,6 +33,7 @@ __all__ = (
     "OpenSearchWarmPartitionInstanceTypeType",
     "OptionStateType",
     "OutboundConnectionStatusCodeType",
+    "OverallChangeStatusType",
     "PackageStatusType",
     "PackageTypeType",
     "ReservedInstancePaymentOptionType",
@@ -193,6 +194,7 @@ OutboundConnectionStatusCodeType = Literal[
     "VALIDATING",
     "VALIDATION_FAILED",
 ]
+OverallChangeStatusType = Literal["COMPLETED", "FAILED", "PENDING", "PROCESSING"]
 PackageStatusType = Literal[
     "AVAILABLE",
     "COPYING",
